#[repr(transparent)]pub struct UserSessionsList {
inner: TypedObjectRef<UserSessionsList, ()>,
phantom: PhantomData<()>,
}Expand description
List of active user sessions for a user.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<UserSessionsList, ()>phantom: PhantomData<()>Implementations
Sourceimpl UserSessionsList
impl UserSessionsList
Sourcepub fn other_sessions(&self) -> <OtherSessionsList as Property>::Value
pub fn other_sessions(&self) -> <OtherSessionsList as Property>::Value
The other user sessions.
Sourcepub fn current_session(
&self,
) -> <RefCell<Option<UserSession>> as Property>::Value
pub fn current_session( &self, ) -> <RefCell<Option<UserSession>> as Property>::Value
The current user session.
Sourcepub fn loading_state(&self) -> <Cell<LoadingState> as Property>::Value
pub fn loading_state(&self) -> <Cell<LoadingState> as Property>::Value
The loading state of the list.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_other_sessions_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_other_sessions_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the other-sessions property
Sourcepub fn connect_current_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_current_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the current-session property
Sourcepub fn connect_loading_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_loading_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the loading-state property
Sourcepub fn connect_is_empty_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_empty_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-empty property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_other_sessions(&self)
pub fn notify_other_sessions(&self)
Notify listeners of a change in the other-sessions property
Sourcepub fn notify_current_session(&self)
pub fn notify_current_session(&self)
Notify listeners of a change in the current-session property
Sourcepub fn notify_loading_state(&self)
pub fn notify_loading_state(&self)
Notify listeners of a change in the loading-state property
Sourcepub fn notify_is_empty(&self)
pub fn notify_is_empty(&self)
Notify listeners of a change in the is-empty property
Sourceimpl UserSessionsList
impl UserSessionsList